<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>Preferences</name>
    <message>
        <source>Retas Level Format</source>
        <translation>Formato de nivel Retas</translation>
    </message>
    <message>
        <source>Adobe Photoshop</source>
        <translation>Adobe Photoshop</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No restrictions for uncompressed avi video</source>
        <translation>Sin restricciones para videos AVI sin compresión</translation>
    </message>
    <message>
        <source>video width must be a multiple of %1</source>
        <translation>el ancho del video debe ser múltiplo de %1</translation>
    </message>
    <message>
        <source>video length must be a multiple of %1</source>
        <translation>la altura del video debe ser múltiplo de %1</translation>
    </message>
    <message>
        <source>No restrictions for this codec</source>
        <translation>Sin restricciones para este compresor</translation>
    </message>
    <message>
        <source>Resolution restrictions:</source>
        <translation>Restricciones de resolución:</translation>
    </message>
    <message>
        <source>It is not possible to communicate with the codec.
 Probably the codec cannot work correctly.</source>
        <translation>No es posible comunicarse con el compresor.
 Es probable que el compresor no esté funcionando correctamente.</translation>
    </message>
    <message>
        <source>%1-%2</source>
        <translation>%1-%2</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Expected %1 argument(s) in %2, got %3</source>
        <translation>Se esperaban %1 argumento(s) en %2, se obtuvieron %3</translation>
    </message>
    <message>
        <source>%1 is not a valid color (valid color names are &apos;red&apos;, &apos;transparent&apos;, &apos;#FF8800&apos;, ecc.)</source>
        <translation>%1 no es un color válido (nombres válidos de color son &apos;red&apos;,  &apos;transparent&apos;, &apos;#FF8800&apos;, etc.)</translation>
    </message>
    <message>
        <source>Vectorization failed</source>
        <translation>Falló la vectorización</translation>
    </message>
    <message>
        <source>Argument doesn&apos;t look like a file path : %1</source>
        <translation>El argumento no parece ser una ruta de archivo: %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image (not empty)</source>
        <translation>Argumento erróneo (%1): debería ser una imagen (no vacía)</translation>
    </message>
    <message>
        <source>Argument &apos;%1&apos; does not look like a FrameId</source>
        <translation>El argumento &apos;%1&apos; no parece ser un identificador de fotogramas</translation>
    </message>
    <message>
        <source>First argument must be a scene : %1</source>
        <translation>El primer argumento debe ser una escena: %1</translation>
    </message>
    <message>
        <source>Can&apos;t render empty scene</source>
        <translation>No es posible procesar una escena vacía</translation>
    </message>
    <message>
        <source>The autocentering failed on the current drawing.</source>
        <translation>El centrado automático falló en el dibujo actual</translation>
    </message>
    <message>
        <source>New Camera  %1</source>
        <translation>Nueva cámara  %1</translation>
    </message>
    <message>
        <source>New Pegbar  %1</source>
        <translation>Nueva barra de sujeción  %1</translation>
    </message>
    <message>
        <source>Set Active Camera  %1 &gt; %2</source>
        <translation>Definir cámara activa  %1 &gt; %2</translation>
    </message>
    <message>
        <source>Remove Spline  %1</source>
        <translation>Eliminar curva  %1</translation>
    </message>
    <message>
        <source>New Motion Path  %1</source>
        <translation>Nueva trayectoria de movimiento  %1</translation>
    </message>
    <message>
        <source>Link Motion Path  %1 &gt; %2</source>
        <translation>Vincular trayectorias de movimiento  %1 &gt; %2</translation>
    </message>
    <message>
        <source>Remove Object  %1</source>
        <translation>Eliminar objeto  %1</translation>
    </message>
    <message>
        <source>Remove Column  </source>
        <translation>Eliminar columna</translation>
    </message>
    <message>
        <source>Load into Current Palette  &gt; %1</source>
        <translation>Cargar en paleta actual  &gt; %1</translation>
    </message>
    <message>
        <source>Replace with Current Palette  &gt; %1</source>
        <translation>Reemplazar con paleta actual  &gt; %1</translation>
    </message>
    <message>
        <source>Delete Studio Palette  : %1</source>
        <translation>Borrar paleta de estudio: %1</translation>
    </message>
    <message>
        <source>Create Studio Palette  : %1</source>
        <translation>Crear paleta de estudio: %1</translation>
    </message>
    <message>
        <source>Delete Studio Palette Folder  : %1</source>
        <translation>Borrar carpeta de paleta de estudio: %1</translation>
    </message>
    <message>
        <source>Create Studio Palette Folder  : %1</source>
        <translation>Crear carpeta de paleta de estudio: %1</translation>
    </message>
    <message>
        <source>Move Studio Palette Folder  : %1 : %2 &gt; %3</source>
        <translation>Mover carpeta de paleta de estudio: %1 : %2 &gt; %3</translation>
    </message>
    <message>
        <source>Arrange Styles  in Palette %1</source>
        <translation>Ordenar estilos en paleta %1</translation>
    </message>
    <message>
        <source>Create Style#%1  in Palette %2</source>
        <translation>Crear estilo № %1  en paleta %2</translation>
    </message>
    <message>
        <source>Add Style  to Palette %1</source>
        <translation>Agregar estilo a paleta %1</translation>
    </message>
    <message>
        <source>Add Page %1 to Palette %2</source>
        <translation>Agregar página %1 a paleta %2</translation>
    </message>
    <message>
        <source>Delete Page %1 from Palette %2</source>
        <translation>Borrar página %1 de paleta %2</translation>
    </message>
    <message>
        <source>Load Color Model %1  to Palette %2</source>
        <translation>Cargar modelo de color %1  en paleta %2</translation>
    </message>
    <message>
        <source>Move Page</source>
        <translation>Mover página</translation>
    </message>
    <message>
        <source>Rename Page  %1 &gt; %2</source>
        <translation>Renombrar página  %1 &gt; %2</translation>
    </message>
    <message>
        <source>Rename Style#%1 in Palette%2  : %3 &gt; %4</source>
        <translation>Renombrar estilo № %1 en paleta %2  : %3 &gt; %4</translation>
    </message>
    <message>
        <source>Add Fx  : </source>
        <translation>Agregar efecto: </translation>
    </message>
    <message>
        <source>Insert Fx  : </source>
        <translation>Insertar efecto: </translation>
    </message>
    <message>
        <source>Create Linked Fx  : %1</source>
        <translation>Crear efecto vinculado: %1</translation>
    </message>
    <message>
        <source>Replace Fx  : </source>
        <translation>Reemplazar efecto: </translation>
    </message>
    <message>
        <source>Unlink Fx  : %1 - - %2</source>
        <translation>Desvincular efecto: %1 - - %2</translation>
    </message>
    <message>
        <source>Make Macro Fx  : %1</source>
        <translation>Crear macro efecto: %1</translation>
    </message>
    <message>
        <source>Explode Macro Fx  : %1</source>
        <translation>Disolver macro efecto: %1</translation>
    </message>
    <message>
        <source>Create Output Fx</source>
        <translation>Crear efecto de salida</translation>
    </message>
    <message>
        <source>Connect to Xsheet  : </source>
        <translation>Conectar a planilla: </translation>
    </message>
    <message>
        <source>Disconnect from Xsheet  : </source>
        <translation>Desconectar de planilla: </translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Borrar vínculo</translation>
    </message>
    <message>
        <source>Delete Fx Node : %1</source>
        <translation>Borrar nodo de efecto: %1</translation>
    </message>
    <message>
        <source>Paste Fx  :  </source>
        <translation>Pegar efecto: </translation>
    </message>
    <message>
        <source>Disconnect Fx</source>
        <translation>Desconectar efecto</translation>
    </message>
    <message>
        <source>Connect Fx : %1 - %2</source>
        <translation>Conectar efecto: %1 - %2</translation>
    </message>
    <message>
        <source>Rename Fx : %1 &gt; %2</source>
        <translation>Renombrar efecto: %1 &gt; %2</translation>
    </message>
    <message>
        <source>Group Fx</source>
        <translation>Agrupar efecto</translation>
    </message>
    <message>
        <source>Ungroup Fx</source>
        <translation>Desagrupar efecto</translation>
    </message>
    <message>
        <source>Rename Group  : %1 &gt; %2</source>
        <translation>Renombrar grupo: %1 &gt; %2</translation>
    </message>
    <message>
        <source>Set Keyframe</source>
        <translation>Marcar clave</translation>
    </message>
    <message>
        <source>Remove Keyframe</source>
        <translation>Eliminar clave</translation>
    </message>
    <message>
        <source>Cycle</source>
        <translation>Ciclo</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Mover</translation>
    </message>
    <message>
        <source>Edit Rotation</source>
        <translation>Editar rotación</translation>
    </message>
    <message>
        <source>Move X</source>
        <translation>Mover en X</translation>
    </message>
    <message>
        <source>Move Y</source>
        <translation>Mover en Y</translation>
    </message>
    <message>
        <source>Move Z</source>
        <translation>Mover en Z</translation>
    </message>
    <message>
        <source>Edit Stack Order</source>
        <translation>Editar orden</translation>
    </message>
    <message>
        <source>Edit Scale W</source>
        <translation>Editar escala H</translation>
    </message>
    <message>
        <source>Edit Scale H</source>
        <translation>Editar escala V</translation>
    </message>
    <message>
        <source>Edit Scale</source>
        <translation>Editar escala</translation>
    </message>
    <message>
        <source>Edit PosPath</source>
        <translation>Editar tray. mov.</translation>
    </message>
    <message>
        <source>Edit Shear X</source>
        <translation>Editar inclinación X</translation>
    </message>
    <message>
        <source>Edit Shear Y</source>
        <translation>Editar inclinación Y</translation>
    </message>
    <message>
        <source>%1  %2  Frame : %3</source>
        <translation>%1  %2  fotograma: %3</translation>
    </message>
    <message>
        <source>Set Keyframe   %1 at frame %2</source>
        <translation>Marcar clave   %1 en fotograma %2</translation>
    </message>
    <message>
        <source>Remove Keyframe   %1 at frame %2</source>
        <translation>Eliminar clave   %1 en fotograma %2</translation>
    </message>
    <message>
        <source>Move Center   %1  Frame %2</source>
        <translation>Mover centro   %1  fotograma %2</translation>
    </message>
    <message>
        <source>color model</source>
        <translation>modelo de color</translation>
    </message>
    <message>
        <source>Set Picked Position of Style#%1 in Palette%2 : %3,%4</source>
        <translation>Definir posición seleccionada del estilo №%1 en la paleta%2 : %3,%4</translation>
    </message>
    <message>
        <source>Update Colors by Using Picked Positions in Palette %1</source>
        <translation>Actualizar los colores usando las posiciones seleccionadas de la paleta %1</translation>
    </message>
    <message>
        <source>Can&apos;t save</source>
        <translation>No es posible guardar</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Rojo</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Verde</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Azul</translation>
    </message>
    <message>
        <source>DarkYellow</source>
        <translation>AmarilloOscuro</translation>
    </message>
    <message>
        <source>DarkCyan</source>
        <translation>CianOscuro</translation>
    </message>
    <message>
        <source>DarkMagenta</source>
        <translation>MagentaOscuro</translation>
    </message>
    <message>
        <source>Brightness</source>
        <translation>Brillo</translation>
    </message>
    <message>
        <source>Contrast</source>
        <translation>Contraste</translation>
    </message>
    <message>
        <source>HRange</source>
        <translation>Rango tonal</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Grosor de línea</translation>
    </message>
    <message>
        <source>ColorThres</source>
        <translation>Umbral de color</translation>
    </message>
    <message>
        <source>WhiteThres</source>
        <translation>Umbral de blanco</translation>
    </message>
    <message>
        <source>Toggle Autopaint Option  Palette : %1  Style#%2</source>
        <translation>Pintar automáticamente al rellenar  Paleta: %1  Estilo №%2</translation>
    </message>
    <message>
        <source>Can&apos;t undo rename palette</source>
        <translation>No es posible deshacer el cambio de nombre de la paleta</translation>
    </message>
    <message>
        <source>Can&apos;t undo move palette</source>
        <translation>No es posible deshacer el cambio de ubicación de la paleta</translation>
    </message>
    <message>
        <source>Can&apos;t redo rename palette</source>
        <translation>No es posible rehacer el cambio de nombre de la paleta</translation>
    </message>
    <message>
        <source>Can&apos;t redo move palette</source>
        <translation>No es posible rehacer el cambio de ubicación de la paleta</translation>
    </message>
    <message>
        <source>Rename Studio Palette : %1 &gt; %2</source>
        <translation>Renombrar paleta de estudio : %1 &gt; %2</translation>
    </message>
    <message>
        <source>Xsheet</source>
        <translation>Planilla</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Línea de T.</translation>
    </message>
    <message>
        <source>Failed to save the following resources:
</source>
        <translation>Falla al guardar los siguientes recursos:
</translation>
    </message>
    <message>
        <source>Failed to save palette.</source>
        <translation>Falla al guardar paleta.</translation>
    </message>
    <message>
        <source>and %1 more item(s).</source>
        <translation>y %1 elemento(s) más.</translation>
    </message>
    <message>
        <source>Orange</source>
        <translation>Naranja</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>Amarillo</translation>
    </message>
    <message>
        <source>Light Green</source>
        <translation>Verde claro</translation>
    </message>
    <message>
        <source>Light Blue</source>
        <translation>Azul claro</translation>
    </message>
    <message>
        <source>Dark Blue</source>
        <translation>Azul oscuro</translation>
    </message>
    <message>
        <source>Purple</source>
        <translation>Morado</translation>
    </message>
    <message>
        <source>Pink</source>
        <translation>Rosa</translation>
    </message>
    <message>
        <source>Dark Pink</source>
        <translation>Rosa oscuro</translation>
    </message>
    <message>
        <source>White</source>
        <translation>Blanco</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::CenterlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>No es posible vectorizar un nivel %1</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>No es posible vectorizar un nivel sin fotogramas</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>No es posible vectorizar una imagen %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>Argumento erróneo (%1): debería ser una imagen o un nivel</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::FilePath</name>
    <message>
        <source>&quot;%1&quot;</source>
        <translation>&quot;%1&quot;</translation>
    </message>
    <message>
        <source>can&apos;t concatenate an absolute path : %1</source>
        <translation>no es posible concatenar una ruta absoluta: %1</translation>
    </message>
    <message>
        <source>%1 is not a directory</source>
        <translation>%1 no es un directorio</translation>
    </message>
    <message>
        <source>can&apos;t read directory %1</source>
        <translation>no es posible leer el directorio %1</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Image</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>El archivo %1 no existe</translation>
    </message>
    <message>
        <source>Loaded first frame of %1</source>
        <translation>Se cargó el primer fotograma de %1</translation>
    </message>
    <message>
        <source>Unexpected error while reading image</source>
        <translation>Error inesperado al leer la imagen</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation>Tipo de archivo no reconocido:</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 image to this file type : %2</source>
        <translation>No es posible guardar una imagen %1 en este tipo de archivo: %2</translation>
    </message>
    <message>
        <source>Unexpected error while writing image</source>
        <translation>Error inesperado al escribir la imagen</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ImageBuilder</name>
    <message>
        <source>Bad argument (%1): should be &apos;Raster&apos; or ToonzRaster&apos;</source>
        <translation>Argumento erróneo (%1): debería ser &apos;Raster&apos; o &apos;ToonzRaster&apos;</translation>
    </message>
    <message>
        <source>ImageBuilder(%1 image)</source>
        <translation>Constructor de imágenes (imagen %1)</translation>
    </message>
    <message>
        <source>%1 : %2</source>
        <translation>%1 : %2</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a Transformation</source>
        <translation>Argumento erróneo (%1): debería ser una transformación</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Level</name>
    <message>
        <source>%1 frames</source>
        <translation>%1 fotogramas</translation>
    </message>
    <message>
        <source>Bad argument (%1). It should be FilePath or string</source>
        <translation>Argumento erróneo (%1). Debería ser una ruta de archivo o una cadena</translation>
    </message>
    <message>
        <source>Exception loading level (%1)</source>
        <translation>Excepción al cargar un nivel (%1)</translation>
    </message>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>El archivo %1 no existe</translation>
    </message>
    <message>
        <source>File %1 is unsupported</source>
        <translation>El archivo %1 no es soportado</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation>Excepción al leer %1</translation>
    </message>
    <message>
        <source>Can&apos;t save an empty level</source>
        <translation>No es posible guardar un nivel vacío</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation>Tipo de archivo no reconocido:</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 level to this file type : %2</source>
        <translation>No es posible guardar un nivel %1 en este tipo de archivo: %2</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation>Excepción al escribir %1</translation>
    </message>
    <message>
        <source>frame index (%1) must be a number</source>
        <translation>el identificador de fotogramas (%1) debe ser numérico</translation>
    </message>
    <message>
        <source>frame index (%1) is out of range (0-%2)</source>
        <translation>el identificador de fotogramas (%1) se encuentra fuera de rango (0-%2)</translation>
    </message>
    <message>
        <source>second argument (%1) is not an image</source>
        <translation>el segundo argumento (%1) no es una imagen</translation>
    </message>
    <message>
        <source>can not insert a %1 image into a level</source>
        <translation>no es posible insertar una imagen %1 en un nivel</translation>
    </message>
    <message>
        <source>can not insert a %1 image to a %2 level</source>
        <translation>no es posible insertar una imagen %1 en un nivel %2</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::OutlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>No es posible vectorizar un nivel %1</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>No es posible vectorizar un nivel sin fotogramas</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>No es posible vectorizar una imagen %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>Argumento erróneo (%1): debería ser una imagen o un nivel</translation>
    </message>
    <message>
        <source>Invalid color : </source>
        <translation>Color inválido: </translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Rasterizer</name>
    <message>
        <source>Expected a vector image: %1</source>
        <translation>Se esperaba una imagen vectorial: %1</translation>
    </message>
    <message>
        <source>Expected a vector level: %1</source>
        <translation>Se esperaba un nivel vectorial: %1</translation>
    </message>
    <message>
        <source>Argument must be a vector level or image : </source>
        <translation>El argumento debe ser un nivel o imagen vectorial: </translation>
    </message>
    <message>
        <source>%1 has no palette</source>
        <translation>%1 no contiene una paleta</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Scene</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>El archivo %1 no existe</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation>Excepción al leer %1</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation>Excepción al escribir %1</translation>
    </message>
    <message>
        <source>Bad level type (%1): must be Vector,Raster or ToonzRaster</source>
        <translation>Tipo de nivel erróneo (%1): debe ser vectorial, imagen o ToonzRaster</translation>
    </message>
    <message>
        <source>Can&apos;t add the level: name(%1) is already used</source>
        <translation>No es posible agregar el nivel: el nombre (%1) ya se encuentra en uso</translation>
    </message>
    <message>
        <source>Can&apos;t load this kind of file as a level : %1</source>
        <translation>No es posible cargar este tipo de archivo como un nivel: %1</translation>
    </message>
    <message>
        <source>Could not load level %1</source>
        <translation>No fue posible cargar el nivel %1</translation>
    </message>
    <message>
        <source>Level is not included in the scene : %1</source>
        <translation>El nivel no se encuentra incluido en la escena: %1</translation>
    </message>
    <message>
        <source>%1 : Expected a Level instance or a level name</source>
        <translation>%1: Se esperaba una instancia de nivel o un nombre de nivel</translation>
    </message>
    <message>
        <source>Level &apos;%1&apos; is not included in the scene</source>
        <translation>El nivel &apos;%1&apos; no se encuentra incluido en la escena</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ToonzRasterConverter</name>
    <message>
        <source>Can&apos;t convert a %1 level</source>
        <translation>No es posible convertir un nivel %1</translation>
    </message>
    <message>
        <source>Can&apos;t convert a level with no frames</source>
        <translation>No es posible convertir un nivel sin fotogramas</translation>
    </message>
    <message>
        <source>Can&apos;t convert a %1 image</source>
        <translation>No es posible convertir una imagen %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a raster Level or a raster Image</source>
        <translation>Argumento erróneo (%1): debería ser un nivel de imagen o una imagen</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Transform</name>
    <message>
        <source>Identity</source>
        <translation>Identidad</translation>
    </message>
    <message>
        <source>Translation(%1,%2)</source>
        <translation>Traslación(%1, %2)</translation>
    </message>
    <message>
        <source>Rotation(%1)</source>
        <translation>Rotación(%1)</translation>
    </message>
    <message>
        <source>Scale(%1%)</source>
        <translation>Escala(%1%)</translation>
    </message>
    <message>
        <source>Scale(%1%, %2%)</source>
        <translation>Escala(%1%, %2%)</translation>
    </message>
    <message>
        <source>Transform(%1, %2, %3;  %4, %5, %6)</source>
        <translation>Transformación(%1, %2, %3;  %4, %5, %6)</translation>
    </message>
</context>
</TS>
